abacusai.agent_version — AbacusAI documentation

# abacusai.agent_version

## Classes

`AgentVersion` | A version of an AI agent.

## Module Contents

class abacusai.agent_version.AgentVersion(client, agentVersion=None, status=None, agentId=None, agentConfig=None, publishingStartedAt=None, publishingCompletedAt=None, pendingDeploymentIds=None, failedDeploymentIds=None, error=None, agentExecutionConfig=None, codeSource={}, workflowGraph={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A version of an AI agent.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - agentVersion (str) – The unique identifier of an agent version.

    - status (str) – The current status of the model.

    - agentId (str) – A reference to the agent this version belongs to.

    - agentConfig (dict) – The config options used to create this agent.

    - publishingStartedAt (str) – The start time and date of the training process in ISO-8601 format.

    - publishingCompletedAt (str) – The end time and date of the training process in ISO-8601 format.

    - pendingDeploymentIds (list) – List of deployment IDs where deployment is pending.

    - failedDeploymentIds (list) – List of failed deployment IDs.

    - error (str) – Relevant error if the status is FAILED.

    - agentExecutionConfig (dict) – The config for arguments used to execute the agent.

    - codeSource (CodeSource) – If a python model, information on where the source code is located.

    - workflowGraph (WorkflowGraph) – The workflow graph for the agent.

  agent_version = None
  status = None
  agent_id = None
  agent_config = None
  publishing_started_at = None
  publishing_completed_at = None
  pending_deployment_ids = None
  failed_deployment_ids = None
  error = None
  agent_execution_config = None
  code_source
  workflow_graph
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      AgentVersion

  describe()

    Retrieves a full description of the specified agent version.

    Parameters:

      agent_version (str) – Unique string identifier of the agent version.

    Returns:

      A agent version.

    Return type:

      AgentVersion

  wait_for_publish(timeout=None)

    A waiting call until agent gets published.

    Parameters:

      timeout (int) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Gets the status of the model version under training.

    Returns:

      A string describing the status of a model training (pending, complete, etc.).

    Return type:

      str